@@ -21,6 +21,7 @@ languages including C/C++ (doesn't require all the header files).
 For more information visit http://www.lizard.ws
 """
 from __future__ import print_function, division
+import codecs
 import sys
 import itertools
 import re
@@ -37,27 +38,38 @@ except ImportError:
     sys.stderr.write("Cannot find the lizard_languages module.")
     sys.exit(2)
 try:
+    from lizard_ext import version
     from lizard_ext import print_xml
+    from lizard_ext import print_csv
     from lizard_ext import html_output
+    from lizard_ext import auto_open, auto_read
 except ImportError:
-    pass
-
-VERSION = "1.12.0"
+    sys.stderr.write("Cannot find the lizard_ext modules.")
 
 DEFAULT_CCN_THRESHOLD, DEFAULT_WHITELIST, \
     DEFAULT_MAX_FUNC_LENGTH = 15, "whitelizard.txt", 1000
 
 
-def analyze(paths, exclude_pattern=None, threads=1, exts=None, lans=None):
+# pylint: disable-msg=too-many-arguments
+def analyze(paths, exclude_pattern=None, threads=1, exts=None,
+            lans=None):
     '''
     returns an iterator of file information that contains function
     statistics.
     '''
     exclude_pattern = exclude_pattern or []
-    extensions = exts or []
     files = get_all_source_files(paths, exclude_pattern, lans)
+    return analyze_files(files, threads, exts)
+
+
+def analyze_files(files, threads=1, exts=None):
+    extensions = exts or get_extensions([])
     file_analyzer = FileAnalyzer(extensions)
-    return map_files_to_analyzer(files, file_analyzer, threads)
+    result = map_files_to_analyzer(files, file_analyzer, threads)
+    for extension in extensions:
+        if hasattr(extension, 'cross_file_process'):
+            result = extension.cross_file_process(result)
+    return result
 
 
 def _extension_arg(parser):
@@ -65,10 +77,9 @@ def _extension_arg(parser):
                         help='''User the extensions. The available extensions
                         are: -Ecpre: it will ignore code in the #else branch.
                         -Ewordcount: count word frequencies and generate tag
-                        cloud. -Efans: count the fan in and fan out of
-                        functions. -Eoutside: include the global code as one
+                        cloud. -Eoutside: include the global code as one
                         function.  -EIgnoreAssert: to ignore all code in
-                        assert''',
+                        assert. -ENS: count nested control structures.''',
                         action="append",
                         dest="extensions",
                         default=[])
@@ -90,7 +101,7 @@ def arg_parser(prog=None):
     parser = ArgumentParser(prog=prog)
     parser.add_argument('paths', nargs='*', default=['.'],
                         help='list of the filename/paths.')
-    parser.add_argument('--version', action='version', version=VERSION)
+    parser.add_argument('--version', action='version', version=version)
     parser.add_argument("-l", "--languages",
                         help='''List the programming languages you want to
                         analyze. if left empty, it'll search for all languages
@@ -113,6 +124,18 @@ def arg_parser(prog=None):
                         type=int,
                         dest="CCN",
                         default=DEFAULT_CCN_THRESHOLD)
+    parser.add_argument("-f", "--input_file",
+                        help='''get a list of filenames from the given file
+                        ''',
+                        type=str,
+                        dest="input_file")
+    parser.add_argument("-o", "--output_file",
+                        help='''Output file. The output format is inferred
+                        from the file extension (e.g. .html), unless it is
+                        explicitly specified (e.g. using --xml).
+                        ''',
+                        type=str,
+                        dest="output_file")
     parser.add_argument("-L", "--length",
                         help='''Threshold for maximum function length
                         warning. The default value is %d.
@@ -132,16 +155,27 @@ def arg_parser(prog=None):
                         action="store_const",
                         const=print_clang_style_warning,
                         dest="printer")
+    parser.add_argument("--warning-msvs",
+                        help='''Show warnings only, using Visual Studio's
+                        warning format for printing warnings.
+                        https://msdn.microsoft.com/en-us/library/yxkt8b26.aspx
+                        ''',
+                        action="store_const",
+                        const=print_msvs_style_warning,
+                        dest="printer")
     parser.add_argument("-i", "--ignore_warnings",
                         help='''If the number of warnings is equal or less
-                        than the number,
-                        the tool will exit normally, otherwise it will generate
-                        error. Useful in makefile for legacy code.''',
+                        than the number, the tool will exit normally;
+                        otherwise, it will generate error.
+                        If the number is negative,
+                        the tool exits normally
+                        regardless of the number of warnings.
+                        Useful in makefile for legacy code.''',
                         type=int,
                         dest="number",
                         default=0)
     parser.add_argument("-x", "--exclude",
-                        help='''Exclude files that match this pattern. * matches
+                        help='''Exclude files that match the pattern. * matches
                         everything,
                         ? matches any single character, "./folder/*" exclude
                         everything in the folder recursively. Multiple patterns
@@ -164,13 +198,21 @@ def arg_parser(prog=None):
                         action="store_const",
                         const=print_xml,
                         dest="printer")
+    parser.add_argument("--csv",
+                        help='''Generate CSV output as a transform of the
+                        default output''',
+                        action="store_const",
+                        const=print_csv,
+                        dest="printer")
     parser.add_argument("-H", "--html",
                         help='''Output HTML report''',
                         action="store_const",
                         const=html_output,
                         dest="printer")
     parser.add_argument("-m", "--modified",
-                        help="Calculate modified cyclomatic complexity number",
+                        help='''Calculate modified cyclomatic complexity number
+                        , which count a switch/case with multiple cases as
+                        one CCN.''',
                         action="append_const",
                         const="modified",
                         dest="extensions",
@@ -204,7 +246,29 @@ def arg_parser(prog=None):
     return parser
 
 
-class FunctionInfo(object):  # pylint: disable=R0902
+class Nesting(object):  # pylint: disable=R0903
+    '''
+    Nesting represent one level of nesting in any programming language.
+    '''
+    @property
+    def name_in_space(self):
+        return ''
+
+
+BARE_NESTING = Nesting()
+
+
+class Namespace(Nesting):  # pylint: disable=R0903
+
+    def __init__(self, name):
+        self.name = name
+
+    @property
+    def name_in_space(self):
+        return self.name + "::" if self.name else ''
+
+
+class FunctionInfo(Nesting):  # pylint: disable=R0902
 
     def __init__(self, name, filename, start_line=0, ccn=1):
         self.cyclomatic_complexity = ccn
@@ -214,33 +278,57 @@ class FunctionInfo(object):  # pylint: disable=R0902
         self.long_name = name
         self.start_line = start_line
         self.end_line = start_line
-        self.parameters = []
+        self.full_parameters = []
         self.filename = filename
-        self.indent = -1
+        self.top_nesting_level = -1
         self.length = 0
         self.fan_in = 0
         self.fan_out = 0
+        self.general_fan_out = 0
+
+    @property
+    def name_in_space(self):
+        return self.name + "."
+
+    @property
+    def unqualified_name(self):
+        '''
+        name without qualification like namespaces or classes.
+        Just the bare name without '::'.
+        '''
+        return self.name.split('::')[-1]
 
     location = property(lambda self:
                         " %(name)s@%(start_line)s-%(end_line)s@%(filename)s"
                         % self.__dict__)
 
-    parameter_count = property(lambda self: len(self.parameters))
+    parameter_count = property(lambda self: len(self.full_parameters))
+
+    @property
+    def parameters(self):
+        matches = [re.search(r'(\w+)(\s=.*)?$', f)
+                   for f in self.full_parameters]
+        return [m.group(1) for m in matches if m]
 
     def add_to_function_name(self, app):
         self.name += app
         self.long_name += app
 
     def add_to_long_name(self, app):
+        if self.long_name:
+            if self.long_name[-1].isalpha() and app[0].isalpha():
+                self.long_name += ' '
         self.long_name += app
 
     def add_parameter(self, token):
         self.add_to_long_name(" " + token)
 
-        if not self.parameters or token == ",":
-            self.parameters.append(token)
+        if not self.full_parameters:
+            self.full_parameters.append(token)
+        elif token == ",":
+            self.full_parameters.append('')
         else:
-            self.parameters[-1] = token
+            self.full_parameters[-1] += " " + token
 
 
 class FileInformation(object):  # pylint: disable=R0903
@@ -268,7 +356,56 @@ class FileInformation(object):  # pylint: disable=R0903
         return summary / len(self.function_list) if self.function_list else 0
 
 
+class NestingStack(object):
+
+    def __init__(self):
+        self.nesting_stack = []
+        self.pending_function = None
+        self.function_stack = []
+
+    def with_namespace(self, name):
+        return ''.join([x.name_in_space for x in self.nesting_stack] + [name])
+
+    def add_bare_nesting(self):
+        self.nesting_stack.append(self._create_nesting())
+
+    def add_namespace(self, token):
+        self.pending_function = None
+        self.nesting_stack.append(Namespace(token))
+
+    def start_new_function_nesting(self, function):
+        self.pending_function = function
+
+    def _create_nesting(self):
+        tmp = self.pending_function
+        self.pending_function = None
+        if tmp:
+            return tmp
+        return BARE_NESTING
+
+    def pop_nesting(self):
+        self.pending_function = None
+        if self.nesting_stack:
+            return self.nesting_stack.pop()
+
+    @property
+    def current_nesting_level(self):
+        return len(self.nesting_stack)
+
+    @property
+    def last_function(self):
+        funs = [f for f in self.nesting_stack if isinstance(f, FunctionInfo)]
+        return funs[-1] if funs else None
+
+
 class FileInfoBuilder(object):
+    '''
+    The builder is also referred as "context" in the code,
+    because each language readers use this builder to build
+    source file and function information and the builder keep
+    the context information that's needed for the building.
+    '''
+
     def __init__(self, filename):
         self.fileinfo = FileInformation(filename, 0)
         self.current_line = 0
@@ -276,6 +413,26 @@ class FileInfoBuilder(object):
         self.newline = True
         self.global_pseudo_function = FunctionInfo('*global*', filename, 0)
         self.current_function = self.global_pseudo_function
+        self.stacked_functions = []
+        self._nesting_stack = NestingStack()
+
+    def __getattr__(self, attr):
+        # delegating to _nesting_stack
+        return getattr(self._nesting_stack, attr)
+
+    def decorate_nesting_stack(self, decorate_class):
+        self._nesting_stack = decorate_class(self._nesting_stack)
+        return self._nesting_stack
+
+    def pop_nesting(self):
+        nest = self._nesting_stack.pop_nesting()
+        if isinstance(nest, FunctionInfo):
+            endline = self.current_function.end_line
+            self.end_of_function()
+            self.current_function = (
+                    self._nesting_stack.last_function or
+                    self.global_pseudo_function)
+            self.current_function.end_line = endline
 
     def add_nloc(self, count):
         self.fileinfo.nloc += count
@@ -285,18 +442,28 @@ class FileInfoBuilder(object):
             self.current_line - self.current_function.start_line + 1
         self.newline = count > 0
 
-    def start_new_function(self, name):
+    def try_new_function(self, name):
         self.current_function = FunctionInfo(
-            name,
+            self.with_namespace(name),
             self.fileinfo.filename,
             self.current_line)
+        self.current_function.top_nesting_level = self.current_nesting_level
+
+    def confirm_new_function(self):
+        self.start_new_function_nesting(self.current_function)
+        self.current_function.cyclomatic_complexity = 1
+
+    def restart_new_function(self, name):
+        self.try_new_function(name)
+        self.confirm_new_function()
+
+    def push_new_function(self, name):
+        self.stacked_functions.append(self.current_function)
+        self.restart_new_function(name)
 
     def add_condition(self, inc=1):
         self.current_function.cyclomatic_complexity += inc
 
-    def reset_complexity(self):
-        self.current_function.cyclomatic_complexity = 1
-
     def add_to_long_function_name(self, app):
         self.current_function.add_to_long_name(app)
 
@@ -310,14 +477,16 @@ class FileInfoBuilder(object):
         if not self.forgive:
             self.fileinfo.function_list.append(self.current_function)
         self.forgive = False
-        self.current_function = self.global_pseudo_function
+        if self.stacked_functions:
+            self.current_function = self.stacked_functions.pop()
+        else:
+            self.current_function = self.global_pseudo_function
 
 
 def preprocessing(tokens, reader):
     if hasattr(reader, "preprocess"):
         return reader.preprocess(tokens)
-    else:
-        return (t for t in tokens if not t.isspace() or t == '\n')
+    return (t for t in tokens if not t.isspace() or t == '\n')
 
 
 def comment_counter(tokens, reader):
@@ -328,6 +497,8 @@ def comment_counter(tokens, reader):
                 yield '\n'
             if comment.strip().startswith("#lizard forgive"):
                 reader.context.forgive = True
+            if "GENERATED CODE" in comment:
+                return
         else:
             yield token
 
@@ -372,7 +543,7 @@ class FileAnalyzer(object):  # pylint: disable=R0903
     def __call__(self, filename):
         try:
             return self.analyze_source_code(
-                filename, open(filename, 'rU').read())
+                filename, auto_read(filename))
         except UnicodeDecodeError:
             sys.stderr.write("Error: doesn't support none utf encoding '%s'\n"
                              % filename)
@@ -383,6 +554,7 @@ class FileAnalyzer(object):  # pylint: disable=R0903
             sys.stderr.write("Error: Fail to parse file '%s'\n"
                              % filename)
             raise
+        return FileInformation(filename, 0, [])
 
     def analyze_source_code(self, filename, code):
         context = FileInfoBuilder(filename)
@@ -395,6 +567,11 @@ class FileAnalyzer(object):  # pylint: disable=R0903
         return context.fileinfo
 
 
+def map_files_to_analyzer(files, analyzer, working_threads):
+    mapmethod = get_map_method(working_threads)
+    return mapmethod(analyzer, files)
+
+
 def warning_filter(option, module_infos):
     for file_info in module_infos:
         if file_info:
@@ -426,7 +603,7 @@ def whitelist_filter(warnings, script=None, whitelist=None):
     def get_whitelist(whitelist):
         if os.path.isfile(whitelist):
             return open(whitelist, mode='r').read()
-        elif whitelist != DEFAULT_WHITELIST:
+        if whitelist != DEFAULT_WHITELIST:
             print("WARNING: !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!")
             print("WARNING: the whitelist \""+whitelist+"\" doesn't exist.")
         return ''
@@ -442,6 +619,24 @@ def whitelist_filter(warnings, script=None, whitelist=None):
 
 
 class OutputScheme(object):
+    '''
+    Collect the schema of the data columns.
+    Each extension can define some additional data columns to
+    the FunctionInfo structure, or even add properties to
+    the FileInformation structure.
+
+    In any extension class, define a class level variable:
+
+        FUNCTION_INFO = {
+            'column_name' : {
+                'caption': 'if defined, will show the column in result',
+                'average_caption': 'if defined, will add average function
+                                    to FileInformation and show in the
+                                    end result.
+            }
+        }
+    '''
+
     def __init__(self, ext):
         self.extensions = ext
         self.items = [
@@ -465,38 +660,44 @@ class OutputScheme(object):
             for caption, part, average in self._ext_member_info()]
         self.items.append({'caption': " location  ", 'value': 'location'})
 
-    @staticmethod
-    def is_string_instance(ext):
-        try:
-            stringtype = basestring
-        except NameError:   # Not compatible with python 3
-            stringtype = str
-        return isinstance(ext.FUNCTION_INFO_PART, stringtype)
+    def patch_for_extensions(self):
+        def _patch(name):
+            setattr(FileInformation, "average_" + name,
+                    property(lambda self: self.functions_average(name)))
+        for item in self.items:
+            if 'avg_caption' in item:
+                _patch(item["value"])
+
+    def any_silent(self):
+        return any(hasattr(ex, 'silent_all_others') for ex in self.extensions)
+
+    def value_columns(self):
+        return [item['value'] for item in self.items]
 
     def _ext_member_info(self):
         for ext in self.extensions:
-            if hasattr(ext, "FUNCTION_CAPTION"):
-                if OutputScheme.is_string_instance(ext):
-                    yield (ext.FUNCTION_CAPTION,
-                           ext.FUNCTION_INFO_PART,
-                           getattr(ext, "AVERAGE_CAPTION", None))
-                else:
-                    for i in range(len(ext.FUNCTION_CAPTION)):
-                        yield (ext.FUNCTION_CAPTION[i],
-                               ext.FUNCTION_INFO_PART[i],
-                               getattr(ext, "AVERAGE_CAPTION", [None]*10)[i])
+            if hasattr(ext, "FUNCTION_INFO"):
+                for key in ext.FUNCTION_INFO:
+                    yield (
+                        ext.FUNCTION_INFO[key].get("caption", None),
+                        key,
+                        ext.FUNCTION_INFO[key].get("average_caption", None))
 
     def captions(self):
-        return "".join(item['caption'] for item in self.items)
+        caps = [item.get('caption') for item in self.items]
+        return "".join(caption for caption in caps if caption)
+
+    @staticmethod
+    def _head(captions):
+        return "\n".join(("=" * len(captions), captions, "-" * len(captions)))
 
     def function_info_head(self):
-        captions = self.captions()
-        return "\n".join(("=" * len(captions), captions, "-" * len(captions)))
+        return self._head(self.captions())
 
     def function_info(self, fun):
         return ''.join(
             str(getattr(fun, item['value'])).rjust(len(item['caption']))
-            for item in self.items)
+            for item in self.items if item['caption'])
 
     def average_captions(self):
         return "".join([
@@ -519,6 +720,15 @@ class OutputScheme(object):
                 for e in self.items[:-1]
                 ]))
 
+    def msvs_warning_format(self):
+        return (
+            "{f.filename}({f.start_line}): warning: {f.name} has " +
+            ", ".join([
+                "{{f.{ext[value]}}} {caption}"
+                .format(ext=e, caption=e['caption'].strip())
+                for e in self.items[:-1]
+                ]))
+
 
 def print_warnings(option, scheme, warnings):
     warning_count = 0
@@ -526,26 +736,45 @@ def print_warnings(option, scheme, warnings):
     warn_str = "!!!! Warnings ({0}) !!!!".format(
         ' or '.join("{0} > {1}".format(
             k, val) for k, val in option.thresholds.items()))
-    print("\n" + "=" * len(warn_str) + "\n" + warn_str)
-    print(scheme.function_info_head())
     for warning in warnings:
+        if warning_count == 0:
+            print("\n" + "=" * len(warn_str) + "\n" + warn_str)
+            print(scheme.function_info_head())
         warning_count += 1
         warning_nloc += warning.nloc
         print(scheme.function_info(warning))
+    if warning_count == 0:
+        print_no_warnings(option)
     return warning_count, warning_nloc
 
 
-def print_total(warning_count, warning_nloc, saved_result, scheme):
-    file_infos = list(file_info for file_info in saved_result if file_info)
-    all_fun = list(itertools.chain(*(file_info.function_list
-                                     for file_info in file_infos)))
-    cnt = len(all_fun) or 1
-    nloc_in_functions = sum([f.nloc for f in all_fun]) or 1
-    all_in_one = FileInformation(
-            "",
-            sum([f.nloc for f in file_infos]),
-            all_fun)
+def print_no_warnings(option):
+    warn_str = "No thresholds exceeded ({0})".format(
+        ' or '.join("{0} > {1}".format(
+            k, val) for k, val in option.thresholds.items()))
+    print("\n" + "=" * len(warn_str) + "\n" + warn_str)
 
+
+class AllResult(object):
+    def __init__(self, result):
+        self.result = list(file_info for file_info in result if file_info)
+        self.all_fun = list(itertools.chain(*(file_info.function_list
+                                            for file_info in self.result)))
+
+    def function_count(self):
+        return len(self.all_fun) or 1
+
+    def nloc_in_functions(self):
+        return sum([f.nloc for f in self.all_fun]) or 1
+
+    def as_fileinfo(self):
+        return FileInformation(
+                    "",
+                    sum([f.nloc for f in self.result]),
+                    self.all_fun)
+
+
+def print_total(warning_count, warning_nloc, all_result, scheme):
     print("=" * 90)
     print("Total nloc  " + scheme.average_captions() + "  Fun Cnt  Warning"
           " cnt   Fun Rt   nloc Rt")
@@ -555,32 +784,29 @@ def print_total(warning_count, warning_nloc, saved_result, scheme):
         scheme.average_formatter() +
         "{function_count:9d}{warning_count:13d}" +
         "{function_rate:10.2f}{nloc_rate:8.2f}").format(
-                  module=all_in_one,
-                  function_count=cnt,
+                  module=all_result.as_fileinfo(),
+                  function_count=all_result.function_count(),
                   warning_count=warning_count,
-                  function_rate=(warning_count/cnt),
-                  nloc_rate=(warning_nloc/nloc_in_functions)))
+                  function_rate=(warning_count/all_result.function_count()),
+                  nloc_rate=(warning_nloc/all_result.nloc_in_functions())))
 
 
-def print_and_save_modules(all_modules, extensions, scheme):
-    all_functions = []
+def print_and_save_modules(all_fileinfos, scheme):
+    saved_fileinfos = []
     print(scheme.function_info_head())
-    for module_info in all_modules:
-        for extension in extensions:
-            if hasattr(extension, 'reduce'):
-                extension.reduce(module_info)
-            if hasattr(extension, 'fans'):
-                extension.fans(module_info)
+    for module_info in all_fileinfos:
         if module_info:
-            all_functions.append(module_info)
+            saved_fileinfos.append(module_info)
             for fun in module_info.function_list:
-                print(scheme.function_info(fun))
-    print("--------------------------------------------------------------")
-    print("%d file analyzed." % (len(all_functions)))
+                try:
+                    print(scheme.function_info(fun))
+                except UnicodeEncodeError:
+                    print("Found ill-formatted unicode function name.")
+    print("%d file analyzed." % (len(saved_fileinfos)))
     print("==============================================================")
     print("NLOC   " + scheme.average_captions() + " function_cnt    file")
     print("--------------------------------------------------------------")
-    for module_info in all_functions:
+    for module_info in saved_fileinfos:
         print((
             "{module.nloc:7d}" +
             scheme.average_formatter() +
@@ -588,38 +814,51 @@ def print_and_save_modules(all_modules, extensions, scheme):
             "     {module.filename}").format(
             module=module_info,
             function_count=len(module_info.function_list)))
-    return all_functions
+    return saved_fileinfos
 
 
 def get_warnings(code_infos, option):
     warnings = whitelist_filter(warning_filter(option, code_infos),
                                 whitelist=option.whitelist)
-    if isinstance(option.sorting, list) and len(option.sorting) > 0:
+    if isinstance(option.sorting, list) and option.sorting:
         warnings = sorted(warnings, reverse=True, key=lambda x: getattr(
             x, option.sorting[0]))
     return warnings
 
 
-def print_result(result, option, scheme):
-    result = print_and_save_modules(result, option.extensions, scheme)
+def print_result(result, option, scheme, total_factory):
+    result = print_and_save_modules(result, scheme)
     warnings = get_warnings(result, option)
     warning_count, warning_nloc = print_warnings(option, scheme, warnings)
-    print_total(warning_count, warning_nloc, result, scheme)
-    for extension in option.extensions:
-        if hasattr(extension, 'print_result'):
-            extension.print_result()
+    print_total(warning_count, warning_nloc, total_factory(result), scheme)
     return warning_count
 
 
-def print_clang_style_warning(code_infos, option, scheme):
+def silent_printer(result, *_):
+    '''
+    just to exhaust the result, no output.
+    '''
+    for _ in result:
+        pass
+    return 0
+
+
+def print_clang_style_warning(code_infos, option, scheme, _):
     count = 0
     for warning in get_warnings(code_infos, option):
-
         print(scheme.clang_warning_format().format(f=warning))
         count += 1
     return count
 
 
+def print_msvs_style_warning(code_infos, option, scheme, _):
+    count = 0
+    for warning in get_warnings(code_infos, option):
+        print(scheme.msvs_warning_format().format(f=warning))
+        count += 1
+    return count
+
+
 def get_map_method(working_threads):
     try:
         if working_threads == 1:
@@ -631,15 +870,10 @@ def get_map_method(working_threads):
         return map
 
 
-def map_files_to_analyzer(files, file_analyzer, working_threads):
-    mapmethod = get_map_method(working_threads)
-    return mapmethod(file_analyzer, files)
-
-
 def md5_hash_file(full_path_name):
     ''' return md5 hash of a file '''
     try:
-        with open(full_path_name, mode='r') as source_file:
+        with auto_open(full_path_name, mode='r') as source_file:
             if sys.version_info[0] == 3:
                 code_md5 = hashlib.md5(source_file.read().encode('utf-8'))
             else:
@@ -649,6 +883,8 @@ def md5_hash_file(full_path_name):
         return None
     except UnicodeDecodeError:
         return None
+    except UnicodeEncodeError:
+        return None
 
 
 def get_all_source_files(paths, exclude_patterns, lans):
@@ -689,7 +925,7 @@ def get_all_source_files(paths, exclude_patterns, lans):
 
 def parse_args(argv):
     def extend_parser(parser_to_extend):
-        from argparse import ArgumentParser, Action, ArgumentError
+        from argparse import ArgumentParser
         parser = ArgumentParser(add_help=False)
         _extension_arg(parser)
         opt, _ = parser.parse_known_args(args=argv[1:])
@@ -701,7 +937,7 @@ def parse_args(argv):
     parser = extend_parser(arg_parser(argv[0]))
     opt = parser.parse_args(args=argv[1:])
     opt.extensions = get_extensions(opt.extensions)
-    values = [item['value'] for item in OutputScheme(opt.extensions).items]
+    values = OutputScheme(opt.extensions).value_columns()
     no_fields = (set(opt.sorting) | set(opt.thresholds.keys())) - set(values)
     if no_fields:
         error_message = "Wrong field name '%s'.\n" % ", ".join(no_fields)
@@ -712,24 +948,44 @@ def parse_args(argv):
         opt.thresholds["cyclomatic_complexity"] = opt.CCN
     if "max_nesting_depth" not in opt.thresholds and hasattr(opt, "ND"):
         opt.thresholds["max_nesting_depth"] = opt.ND
+    if "max_nested_structures" not in opt.thresholds and hasattr(opt, "NS"):
+        opt.thresholds["max_nested_structures"] = opt.NS
     if "length" not in opt.thresholds:
         opt.thresholds["length"] = opt.length
+    if "nloc" not in opt.thresholds:
+        opt.thresholds["nloc"] = 1000000
     if "parameter_count" not in opt.thresholds:
         opt.thresholds["parameter_count"] = opt.arguments
+    if opt.output_file:
+        inferred_printer = infer_printer_from_file_ext(opt.output_file)
+        if inferred_printer:
+            if not opt.printer:
+                opt.printer = inferred_printer
+            else:
+                msg = "Warning: overriding output file extension.\n"
+                sys.stderr.write(msg)
     return opt
 
 
-def patch_extension(ext):
-    def _patch(name):
-        setattr(FileInformation, "average_" + name,
-                property(lambda self: self.functions_average(name)))
-    if hasattr(ext, "AVERAGE_CAPTION"):
-        if OutputScheme.is_string_instance(ext):
-            _patch(ext.FUNCTION_INFO_PART)
-        else:
-            for name in ext.FUNCTION_INFO_PART:
-                _patch(name)
-    return ext
+def infer_printer_from_file_ext(path):
+    mapping = {
+        '.csv': print_csv,
+        '.htm': html_output,
+        '.html': html_output,
+        '.xml': print_xml
+    }
+    _, ext = os.path.splitext(path)
+    printer = mapping.get(ext)
+    return printer
+
+
+def open_output_file(path):
+    try:
+        return codecs.open(path, 'w', encoding='utf8')
+    except OSError:
+        msg = "Error: failed to open output file '{}'\n.".format(path)
+        sys.stderr.write(msg)
+        sys.exit(2)
 
 
 def get_extensions(extension_names):
@@ -737,7 +993,7 @@ def get_extensions(extension_names):
 
     def expand_extensions(existing):
         for name in extension_names:
-            ext = patch_extension(
+            ext = (
                     im('lizard_ext.lizard' + name.lower())
                     .LizardExtension()
                     if isinstance(name, str) else name)
@@ -759,19 +1015,46 @@ def get_extensions(extension_names):
 analyze_file = FileAnalyzer(get_extensions([]))  # pylint: disable=C0103
 
 
-def lizard_main(argv):
-    options = parse_args(argv)
+def main(argv=None):
+    """Command-line entrance to Lizard.
+
+    Args:
+        argv: Arguments vector; if None, sys.argv by default.
+    """
+    options = parse_args(argv or sys.argv)
     printer = options.printer or print_result
+    schema = OutputScheme(options.extensions)
+    if schema.any_silent():
+        printer = silent_printer
+    schema.patch_for_extensions()
+    if options.input_file:
+        options.paths = auto_read(options.input_file).splitlines()
+    original_stdout = sys.stdout
+    output_file = None
+    if options.output_file:
+        output_file = open_output_file(options.output_file)
+        sys.stdout = output_file
     result = analyze(
         options.paths,
         options.exclude,
         options.working_threads,
         options.extensions,
         options.languages)
-    warning_count = printer(result, options, OutputScheme(options.extensions))
-    if options.number < warning_count:
+    warning_count = printer(result, options, schema, AllResult)
+    print_extension_results(options.extensions)
+    list(result)
+    if output_file:
+        sys.stdout = original_stdout
+        output_file.close()
+    if 0 <= options.number < warning_count:
         sys.exit(1)
 
 
+def print_extension_results(extensions):
+    for extension in extensions:
+        if hasattr(extension, 'print_result'):
+            extension.print_result()
+
+
 if __name__ == "__main__":
-    lizard_main(sys.argv)
+    main()
