@@ -1,5 +1,5 @@
 '''
-This is an extension to lizard. It count the reccurance of every identifier
+This is an extension to lizard. It counts the recurrence of every identifier
 in the source code (ignoring the comments and strings), and then generate
 a tag cloud based on the popularity of the identifiers.
 The tag cloud is generated on an HTML5 canvas. So it will eventually save
@@ -32,14 +32,17 @@ class LizardExtension(object):
                 result[token] = result.get(token, 0) + 1
             yield token
 
-    def reduce(self, fileinfo):
+    def cross_file_process(self, fileinfos):
         '''
         Combine the statistics from each file.
         Because the statistics came from multiple thread tasks. This function
         needs to be called to collect the combined result.
         '''
-        for k, val in fileinfo.wordCount.items():
-            self.result[k] = self.result.get(k, 0) + val
+        for fileinfo in fileinfos:
+            if hasattr(fileinfo, "wordCount"):
+                for k, val in fileinfo.wordCount.items():
+                    self.result[k] = self.result.get(k, 0) + val
+            yield fileinfo
 
     def print_result(self):
         with open(self.HTML_FILENAME, 'w') as html_file:
@@ -73,7 +76,8 @@ class LizardExtension(object):
                         var tagCloud = new TagCloud(canvas.width,
                             canvas.height, ctx);
                         tagCloud.render([''')
-            tags = sorted(self.result, key=self.result.get, reverse=True)[:400]
+            tags = sorted(self.result)
+            tags = sorted(tags, key=self.result.get, reverse=True)[:400]
             for k in tags:
                 html_file.write(
                     ' ' * 40 + '["%s", %d],\n' % (
