@@ -10,6 +10,12 @@ from .swift import SwiftReader
 from .ruby import RubyReader
 from .csharp import CSharpReader
 from .php import PHPReader
+from .scala import ScalaReader
+from .gdscript import GDScriptReader
+from .go import GoReader
+from .lua import LuaReader
+from .rust import RustReader
+from .typescript import TypeScriptReader
 
 
 def languages():
@@ -23,7 +29,14 @@ def languages():
         TTCNReader,
         RubyReader,
         PHPReader,
-        SwiftReader]
+        SwiftReader,
+        ScalaReader,
+        GDScriptReader,
+        GoReader,
+        LuaReader,
+        RustReader,
+        TypeScriptReader
+    ]
 
 
 def get_reader_for(filename):
