@@ -2,7 +2,7 @@
 Language parser for Java
 '''
 
-from .clike import CLikeReader, CLikeStates
+from .clike import CLikeReader, CLikeStates, CLikeNestingStackStates
 
 
 class JavaReader(CLikeReader):
@@ -13,7 +13,9 @@ class JavaReader(CLikeReader):
 
     def __init__(self, context):
         super(JavaReader, self).__init__(context)
-        self.parallel_states = [JavaStates(context)]
+        self.parallel_states = [
+                JavaStates(context),
+                CLikeNestingStackStates(context)]
 
 
 class JavaStates(CLikeStates):  # pylint: disable=R0903
@@ -21,6 +23,10 @@ class JavaStates(CLikeStates):  # pylint: disable=R0903
         if token == '{':
             self._state_dec_to_imp(token)
 
+    def try_new_function(self, name):
+        self.context.try_new_function(name)
+        self._state = self._state_function
+
     def _state_global(self, token):
         if token == '@':
             self._state = self._state_decorator
