@@ -13,19 +13,22 @@ class PHPReader(CodeReader, CCppCommentsMixin):
 
     ext = ['php']
     language_names = ['php']
-    conditions = set(['if', 'elseif', 'for', 'while', '&&', '||', '?', 'catch',
-                      'case'])
+    _conditions = set(['if', 'elseif', 'for', 'while', '&&', '||', '?',
+                       'catch', 'case'])
 
     @staticmethod
-    def generate_tokens(source_code, extra=''):
-        extra += r"|(?:\$\w+)"
-        extra += r"|(?:\<{3}(?P<quote>\w+).*?(?P=quote))"
+    def generate_tokens(source_code, addition='', token_class=None):
+        addition += r"|(?:\$\w+)"
+        addition += r"|(?:\<{3}(?P<quote>\w+).*?(?P=quote))"
         current_pos = 0
-        code_block_pattern = re.compile(r"\<\?(?:php)?(.*?)\?\>", re.M | re.S)
+        code_block_pattern = re.compile(
+                r"\<\?(?:php)?(.*?)(?:(\?\>)|\Z)",
+                re.M | re.S)
         for match in code_block_pattern.finditer(source_code):
             if source_code[current_pos:match.start()]:
                 yield '"' + source_code[current_pos:match.start()] + '"'
-            for token in CodeReader.generate_tokens(match.group(1), extra):
+            for token in CodeReader.generate_tokens(
+                    match.group(1), addition, token_class):
                 yield token
             current_pos = match.end()
         if source_code[current_pos:]:
