@@ -13,8 +13,9 @@ class ScriptLanguageMixIn(object):
             return token[1:]
 
     @staticmethod
-    def generate_common_tokens(source_code, addition):
+    def generate_common_tokens(source_code, addition, match_holder=None):
         _until_end = r"(?:\\\n|[^\n])*"
         return CodeReader.generate_tokens(
             source_code,
-            r"|\#" + _until_end + addition)
+            r"|\#" + _until_end + addition,
+            match_holder)
