@@ -1,37 +1,36 @@
 import unittest
 from mock import patch
 import lizard
-from lizard import lizard_main
 import os
 import sys
 
 
 @patch('lizard.md5_hash_file')
-@patch('lizard.open', create=True)
+@patch('lizard.auto_read', create=True)
 @patch.object(os, 'walk')
 @patch.object(lizard, 'print_result')
 class TestApplication(unittest.TestCase):
 
     def testEmptyResult(self, print_result, os_walk, mock_open, _):
 
-        def check_empty_result(result, options, scheme):
+        def check_empty_result(result, options, scheme, _):
             self.assertEqual([], list(result))
             return 0
 
         os_walk.return_value = [('.', [], [])]
         print_result.side_effect = check_empty_result
-        lizard_main(['lizard'])
+        lizard.main(['lizard'])
 
     def testFilesWithFunction(self, print_result, os_walk, mock_open, _):
-        def check_result(result, options, scheme):
+        def check_result(result, options, scheme, _):
             fileInfos = list(result)
             self.assertEqual(1, len(fileInfos))
             self.assertEqual('foo', fileInfos[0].function_list[0].name)
             return 0
         os_walk.return_value = [('.', [], ['a.cpp'])]
-        mock_open.return_value.read.return_value = "void foo(){}"
+        mock_open.return_value = "void foo(){}"
         print_result.side_effect = check_result
-        lizard_main(['lizard'])
+        lizard.main(['lizard'])
 
 
 class IntegrationTests(unittest.TestCase):
@@ -55,15 +54,15 @@ class IntegrationTests(unittest.TestCase):
         '''
         self.returned_warning_count = 0
 
-    @patch('lizard.open', create=True)
+    @patch('lizard.auto_read', create=True)
     @patch.object(lizard, 'print_result')
     def run_with_mocks(self, argv, src, print_result, mock_open):
-        def store_result(result, options, scheme):
+        def store_result(result, options, scheme, _):
             self.fileInfos = list(result)
             return self.returned_warning_count
-        mock_open.return_value.read.return_value = src
+        mock_open.return_value = src
         print_result.side_effect = store_result
-        lizard_main(argv)
+        lizard.main(argv)
         return self.fileInfos
 
     @patch('lizard.md5_hash_file')
@@ -76,7 +75,8 @@ class IntegrationTests(unittest.TestCase):
         self.runApplicationWithArgv(['lizard'])
         self.assertEqual(7, self.fileInfos[0].function_list[0].cyclomatic_complexity)
 
-    def test_using_the_WordCount_plugin(self):
+    @patch('webbrowser.open')
+    def test_using_the_WordCount_plugin(self, webopen):
         self.runApplicationWithArgv(['lizard', '-EWordCount'])
         self.assertEqual(1, self.fileInfos[0].wordCount["foo"])
 
@@ -89,5 +89,13 @@ class IntegrationTests(unittest.TestCase):
         self.returned_warning_count = 6
         self.runApplicationWithArgv(['lizard', '-C5'])
         mock_exit.assert_called_with(1)
+        self.runApplicationWithArgv(['lizard', '-i5'])
+        mock_exit.assert_called_with(1)
 
-
+    @patch.object(sys, 'exit')
+    def test_exit_code_ignore_warnings(self, mock_exit):
+        self.returned_warning_count = 6
+        self.runApplicationWithArgv(['lizard', '-i6'])
+        self.assertFalse(mock_exit.called)
+        self.runApplicationWithArgv(['lizard', '-i', '-1'])
+        self.assertFalse(mock_exit.called)
