@@ -1,10 +1,10 @@
 import unittest
-from .testHelpers import get_cpp_function_list_with_extnesion
+from .testHelpers import get_cpp_function_list_with_extension
 from lizard_ext.lizardoutside import LizardExtension as CountOutsideComplexity
 
 
 def analyze_with_outside_extension(code):
-    return get_cpp_function_list_with_extnesion(code, CountOutsideComplexity())
+    return get_cpp_function_list_with_extension(code, CountOutsideComplexity())
 
 class Test_complexity_in_c_marco(unittest.TestCase):
 
@@ -22,4 +22,3 @@ class Test_complexity_in_c_marco(unittest.TestCase):
         result = analyze_with_outside_extension("#if a==b\n void fun() {if(1);}\n #if 1")
         self.assertEqual("*global*", result[1].name)
         self.assertEqual(3, result[1].cyclomatic_complexity)
-
