@@ -1,7 +1,7 @@
 import unittest
 from mock import Mock, patch
 from lizard_ext.lizardcpre import LizardExtension as CPreprocessor
-from .testHelpers import get_cpp_function_list_with_extnesion
+from .testHelpers import get_cpp_function_list_with_extension
 from lizard_languages.code_reader import CodeReader
 generate_tokens = CodeReader.generate_tokens
 
@@ -96,12 +96,12 @@ class TestCPreprocessor(unittest.TestCase):
 
 
 def analyze_with_extension(code):
-    return get_cpp_function_list_with_extnesion(code, CPreprocessor())
+    return get_cpp_function_list_with_extension(code, CPreprocessor())
 
 
 class Test_end_2_end(unittest.TestCase):
 
-    def test_exention_in_user(self):
+    def test_extension_in_user(self):
         result = analyze_with_extension("#if\nxxaa#else\nint a(){}\n#endif")
         self.assertEqual(0, len(result))
 
