@@ -1,11 +1,11 @@
 import unittest
-from .testHelpers import get_cpp_function_list_with_extnesion
+from .testHelpers import get_cpp_function_list_with_extension
 from lizard_ext.lizardmccabe import LizardExtension as McCabe
 
 class TestFunctionExitCount(unittest.TestCase):
 
     def test_normal_case(self):
-        result = get_cpp_function_list_with_extnesion("""int fun(){
+        result = get_cpp_function_list_with_extension("""int fun(){
                     switch(x) {
                         case 1: break;
                         case 2: break;
@@ -15,7 +15,7 @@ class TestFunctionExitCount(unittest.TestCase):
         self.assertEqual(4, result[0].cyclomatic_complexity)
 
     def test_fall_through(self):
-        result = get_cpp_function_list_with_extnesion("""int fun(){
+        result = get_cpp_function_list_with_extension("""int fun(){
                     switch(x) {
                         case 1:
                         case 2: break;
@@ -25,7 +25,7 @@ class TestFunctionExitCount(unittest.TestCase):
         self.assertEqual(3, result[0].cyclomatic_complexity)
 
     def test_more(self):
-        result = get_cpp_function_list_with_extnesion("""int fun(){
+        result = get_cpp_function_list_with_extension("""int fun(){
                     switch(x) {
                         case 1:
                         case 2:
@@ -33,4 +33,3 @@ class TestFunctionExitCount(unittest.TestCase):
                     };
                 }""", McCabe())
         self.assertEqual(2, result[0].cyclomatic_complexity)
-
