@@ -4,12 +4,12 @@ from mock import Mock, patch
 from test.helper_stream import StreamStdoutTestCase
 import os
 from lizard import print_warnings, print_and_save_modules, FunctionInfo, FileInformation,\
-    print_result, get_extensions, OutputScheme, get_warnings, print_clang_style_warning,\
-    parse_args
+    print_result, print_extension_results, get_extensions, OutputScheme, get_warnings, print_clang_style_warning,\
+    parse_args, AllResult
 from lizard_ext import xml_output
 
 def print_result_with_scheme(result, option):
-    return print_result(result, option, OutputScheme(option.extensions))
+    return print_result(result, option, OutputScheme(option.extensions), AllResult)
 
 class TestFunctionOutput(StreamStdoutTestCase):
 
@@ -20,33 +20,30 @@ class TestFunctionOutput(StreamStdoutTestCase):
         self.foo = FunctionInfo("foo", 'FILENAME', 100)
 
     def test_function_info_header_should_have_a_box(self):
-        print_and_save_modules([], self.extensions, self.scheme)
+        print_and_save_modules([],  self.scheme)
         self.assertIn("=" * 20, sys.stdout.stream.splitlines()[0])
 
     def test_function_info_header_should_have_the_captions(self):
-        print_and_save_modules([], self.extensions, self.scheme)
-        self.assertEquals("  NLOC    CCN   token  PARAM  length  location  ", sys.stdout.stream.splitlines()[1])
+        print_and_save_modules([],  self.scheme)
+        self.assertEqual("  NLOC    CCN   token  PARAM  length  location  ", sys.stdout.stream.splitlines()[1])
 
     def test_function_info_header_should_have_the_captions_of_external_extensions(self):
-        external_extension = Mock(FUNCTION_CAPTION = "*external_extension*", FUNCTION_INFO_PART ="xx", ordering_index=-1)
-        del external_extension.AVERAGE_CAPTION
+        external_extension = Mock(FUNCTION_INFO = {"xx": {"caption":"*external_extension*"}}, ordering_index=-1)
         extensions = get_extensions([external_extension])
         scheme = OutputScheme(extensions)
-        print_and_save_modules([], extensions, scheme)
-        self.assertEquals("  NLOC    CCN   token  PARAM  length *external_extension* location  ", sys.stdout.stream.splitlines()[1])
+        print_and_save_modules([],  scheme)
+        self.assertEqual("  NLOC    CCN   token  PARAM  length *external_extension* location  ", sys.stdout.stream.splitlines()[1])
 
     def test_print_fileinfo(self):
         self.foo.end_line = 100
         self.foo.cyclomatic_complexity = 16
         fileStat = FileInformation("FILENAME", 1, [self.foo])
-        print_and_save_modules([fileStat], self.extensions, self.scheme)
-        self.assertEquals("       1     16      1      0       0 foo@100-100@FILENAME", sys.stdout.stream.splitlines()[3])
+        print_and_save_modules([fileStat],  self.scheme)
+        self.assertEqual("       1     16      1      0       0 foo@100-100@FILENAME", sys.stdout.stream.splitlines()[3])
 
 
 class Ext(object):
-    FUNCTION_CAPTION = "  ND  "
-    AVERAGE_CAPTION = " Avg.ND "
-    FUNCTION_INFO_PART = "max_nesting_depth"
+    FUNCTION_INFO = {"max_nesting_depth": {"caption": "  ND  ", "average_caption": " Avg.ND "}}
 
 
 class TestWarningOutput(StreamStdoutTestCase):
@@ -63,7 +60,7 @@ class TestWarningOutput(StreamStdoutTestCase):
         self.assertIn("cyclomatic_complexity > 15", sys.stdout.stream)
 
     def test_no_news_is_good_news(self):
-        count = print_clang_style_warning([], self.option, None)
+        count = print_clang_style_warning([], self.option, None, None)
         self.assertEqual('', sys.stdout.stream)
         self.assertEqual(0, count)
 
@@ -72,7 +69,7 @@ class TestWarningOutput(StreamStdoutTestCase):
         self.foo.max_nesting_depth = 10
         fileSummary = FileInformation("FILENAME", 123, [self.foo])
         scheme = OutputScheme([Ext()])
-        count = print_clang_style_warning([fileSummary], self.option, scheme)
+        count = print_clang_style_warning([fileSummary], self.option, scheme, None)
         self.assertIn("FILENAME:100: warning: foo has 1 NLOC, 30 CCN, 1 token, 0 PARAM, 0 length, 10 ND\n", sys.stdout.stream)
         self.assertEqual(1, count)
 
@@ -90,18 +87,18 @@ class TestWarningOutput(StreamStdoutTestCase):
         print_warnings(self.option, self.scheme, (x for x in []))
 
 
-class TestFileOutput(StreamStdoutTestCase):
+class TestFileInformationOutput(StreamStdoutTestCase):
 
     def test_print_and_save_detail_information(self):
         scheme = OutputScheme([])
         fileSummary = FileInformation("FILENAME", 123, [])
-        print_and_save_modules([fileSummary], [], scheme)
+        print_and_save_modules([fileSummary], scheme)
         self.assertIn("    123       0.0     0.0        0.0         0     FILENAME\n", sys.stdout.stream)
 
     def test_print_and_save_detail_information_with_ext(self):
         scheme = OutputScheme([Ext()])
         fileSummary = FileInformation("FILENAME", 123, [])
-        print_and_save_modules([fileSummary], [Ext()], scheme)
+        print_and_save_modules([fileSummary], scheme)
         self.assertIn("Avg.ND", sys.stdout.stream)
         self.assertIn("    123       0.0     0.0        0.0     0.0         0     FILENAME", sys.stdout.stream)
 
@@ -110,7 +107,7 @@ class TestFileOutput(StreamStdoutTestCase):
         scheme = OutputScheme([])
         print_and_save_modules(
                             [FileInformation("FILENAME1", 123, []),
-                             FileInformation("FILENAME2", 123, [])], [], scheme)
+                             FileInformation("FILENAME2", 123, [])], scheme)
         self.assertEqual(1, sys.stdout.stream.count("FILENAME1"))
 
 
@@ -121,11 +118,8 @@ class TestAllOutput(StreamStdoutTestCase):
         self.foo = FunctionInfo("foo", 'FILENAME', 100)
 
     def test_print_extension_results(self):
-        file_infos = []
-        extension = Mock(FUNCTION_CAPTION = "")
-        del extension.AVERAGE_CAPTION
-        option = Mock(CCN=15, thresholds={}, number = 0, extensions = [extension], whitelist='')
-        print_result(file_infos, option, OutputScheme(option.extensions))
+        extension = Mock(FUNCTION_INFO = {})
+        print_extension_results([extension])
         self.assertEqual(1, extension.print_result.call_count)
 
     def test_should_not_print_extension_results_when_not_implemented(self):
@@ -164,10 +158,16 @@ class TestXMLOutput(unittest.TestCase):
     foo = FunctionInfo("foo", '', 100)
     foo.cyclomatic_complexity = 16
     file_infos = [FileInformation('f1.c', 1, [foo])]
-    xml = xml_output(file_infos, True)
+    xml = xml_output(AllResult(file_infos), True)
 
     def test_xml_output(self):
         self.assertIn('''foo at f1.c:100''', self.xml)
 
     def test_xml_stylesheet(self):
-        self.assertIn('''<?xml-stylesheet type="text/xsl" href="https://raw.github.com/terryyin/lizard/master/lizard.xsl"?>''', self.xml)
+        self.assertIn('''<?xml-stylesheet type="text/xsl" href="https://raw.githubusercontent.com/terryyin/lizard/master/lizard.xsl"?>''', self.xml)
+
+    def test_xml_output_on_empty_folder(self):
+        xml_empty = xml_output(AllResult([]), True)
+        self.assertIn('''<sum label="NCSS" value="0"/>''', xml_empty)
+        self.assertIn('''<sum label="CCN" value="0"/>''', xml_empty)
+        self.assertIn('''<sum label="Functions" value="0"/>''', xml_empty)
