@@ -1,9 +1,10 @@
 import unittest
 from lizard_languages.code_reader import CodeReader
-generate_tokens = CodeReader.generate_tokens
+def generate_tokens(source):
+    return [t for t in CodeReader.generate_tokens(source)]
 
 
-class Test_generate_tonken(unittest.TestCase):
+class Test_generate_token(unittest.TestCase):
 
     def check_tokens(self, source, *expect):
         tokens = generate_tokens(source)
@@ -28,6 +29,8 @@ class Test_generate_tonken(unittest.TestCase):
         self.check_tokens("<=", '<=')
         self.check_tokens("||", '||')
         self.check_tokens(">>", '>', '>')
+        self.check_tokens(">>=", '>>=')
+        self.check_tokens("<<=", '<<=')
 
     def test_more(self):
         self.check_tokens("int a{}", 'int', ' ', "a", "{", "}")
@@ -45,12 +48,12 @@ class Test_generate_tonken(unittest.TestCase):
         tokens = generate_tokens('abc\ndef')
         self.assertTrue('def' in tokens)
 
-    def test_with_mutiple_line_string(self):
+    def test_with_multiple_line_string(self):
         tokens = generate_tokens('"sss\nsss" t')
         self.assertTrue('t' in tokens)
 
 
-class Test_generate_tonken_for_marcos(unittest.TestCase):
+class Test_generate_token_for_macros(unittest.TestCase):
 
     def test_define(self):
         define =  '''#define xx()\
@@ -92,7 +95,7 @@ class Test_generate_tonken_for_marcos(unittest.TestCase):
         tokens = generate_tokens(comment)
         self.assertEqual(1, len(tokens))
 
-class Test_generate_tonken_for_comments(unittest.TestCase):
+class Test_generate_token_for_comments(unittest.TestCase):
 
     def test_c_style_comment(self):
         tokens = generate_tokens("/***\n**/")
@@ -122,4 +125,3 @@ class Test_generate_tonken_for_comments(unittest.TestCase):
         comment = '/**a/*/'
         tokens = generate_tokens(comment)
         self.assertListEqual([comment], tokens)
-
