@@ -25,17 +25,17 @@ class Test_analyze_files(unittest.TestCase):
             call_count += 1
         map_files_to_analyzer([], analyzer, 2)
         self.assertEqual(0, call_count)
-        
+
     def test_OneFile(self):
         analyzer = analyzer_mock
         r = map_files_to_analyzer(["filename"], analyzer, 1)
         self.assertEqual(["filename"], [x for x in r])
-        
+
     def test_OneFileMultipleThread(self):
         analyzer = analyzer_mock
         r = map_files_to_analyzer(["filename"], analyzer, 2)
         self.assertEqual(["filename"], [x for x in r])
-    
+
     def test_MoreFiles(self):
         analyzer = analyzer_mock
         r = map_files_to_analyzer(["f1", "f2"], analyzer, 1)
@@ -47,24 +47,26 @@ class Test_analyze_files(unittest.TestCase):
         self.assertSetEqual(set(["f1", "f2"]), set(x for x in r))
 
 
-@patch('lizard.open', create=True)
+@patch('lizard.auto_read', create=True)
 class Test_FileAnalyzer(unittest.TestCase):
-    
+
     def setUp(self):
         self.analyzer = analyze_file
-        
+
     def test_analyze_c_file(self, mock_open):
-        file_handle = mock_open.return_value.read.return_value = "int foo(){haha();\n}"
+        file_handle = mock_open.return_value = "int foo(){haha();\n}"
         r = map_files_to_analyzer(["f1.c"], self.analyzer, 1)
         self.assertEqual(1, len([x for x in r]))
-        
+
+    @unittest.skipIf(sys.platform == 'win32' and sys.version_info < (3, ),
+                     'mock_open does not get patched in child thread (!?)')
     def test_analyze_c_file_with_multiple_thread(self, mock_open):
-        file_handle = mock_open.return_value.read.return_value = "int foo(){haha();\n}"
+        file_handle = mock_open.return_value = "int foo(){haha();\n}"
         r = map_files_to_analyzer(["f1.c"], self.analyzer, 2)
         self.assertEqual(1, len([x for x in r]))
-    
-    def test_fileInfomation(self, mock_open):
-        mock_open.return_value.read.return_value = "int foo(){haha();\n}"
+
+    def test_fileInformation(self, mock_open):
+        mock_open.return_value = "int foo(){haha();\n}"
         r = map_files_to_analyzer(["f1.c"], self.analyzer, 1)
         fileInfo = list(r)[0]
         self.assertEqual(2, fileInfo.nloc)
@@ -126,11 +128,11 @@ class TestWarningFilterWithWhitelist(unittest.TestCase):
         warnings = whitelist_filter([FunctionInfo("class::foo", 'filename')], 'class::foo')
         self.assertEqual(0, len(list(warnings)))
 
-    def test_should_filter_mutiple_functions_defined_on_one_line(self):
+    def test_should_filter_multiple_functions_defined_on_one_line(self):
         warnings = whitelist_filter(self.WARNINGS, 'foo, bar')
         self.assertEqual(0, len(list(warnings)))
 
-    def test_should_filter_mutiple_lines_of_whitelist(self):
+    def test_should_filter_multiple_lines_of_whitelist(self):
         warnings = whitelist_filter(self.WARNINGS, 'foo\n bar')
         self.assertEqual(0, len(list(warnings)))
 
